A shiny server function to implement Cognito Authentication in your shiny app.
cognito_server(
input,
output,
session,
with_cookie = FALSE,
cookiename = "cognitor",
cookie_expire = 7
)reactiveValues (isLogged and userdata) and a callback function to do logout in Cognito.
- Shiny input
- Shiny Output
- Shiny Session
- Create a own cookie when is authenticated in Cognito.
- name for cookie
- Expiration time for cookie
Pablo Pagnone